/**
 * Header file for /dev/tv ioctls
 */
#ifndef TV_H
#define TV_H
#include <linux/ioctl.h>

#define TV_MAJOR	104 /*VIDEO_MAJOR*/
#define TV_MINOR	0   /*143*/

/* The name for our device, as it will appear in /proc/devices */
#define TV_DEVICE_NAME "tv"

#define TV_GET_DEFAULT(x) (current_table[((x) - 0xe430) / 2 + 1])

struct tv_settings_t;
struct tv_reg_t;

struct tv_settings_t
{                                                                       
	int on, force, color, ntsc, flicker, video_rgb, auto_correct_color;
	int u_gain, v_gain;
	int color_lum_delay, color_chrom_delay;
	int color_start, color_stop;
	int sync_amp, blank_amp, u_amp, v_amp;
	int ped_amp;
	int color_coarse, color_fine, color_phase;
	int hsync_start, hsync_stop;
	int hblank_start, hblank_stop;
	int vsync_start, vsync_stop;
	int vblank_start, vblank_stop;
};

struct tv_caps_t
{
	int x, y;	  			/* Max resolution            */
	int x_tot, y_tot; 			/* Res with blanks and syncs */
	int h_refresh_max, v_refresh_max;	/* Max refresh               */
	int h_refresh_min, v_refresh_min;	/* Min refresh               */
	char name[8]; 	  			/* "pal" or "ntsc"           */
};


enum reg_t { reg_grf, reg_crt, reg_tv };

struct tv_reg_t
{
	enum reg_t 	type;
	unsigned int 	index;
	unsigned short	value;
};

#define IOCTL_TV_CONFIG_WRITE	_IOW(TV_MAJOR, 0, struct tv_settings_t *)
#define IOCTL_TV_CONFIG_READ	_IOR(TV_MAJOR, 1, struct tv_settings_t *)
#define IOCTL_TV_GET_REG	_IOR(TV_MAJOR, 2, struct tv_reg_t *)
#define IOCTL_TV_SET_REG	_IOW(TV_MAJOR, 3, struct tv_reg_t *)
#define IOCTL_TV_NEW_MODE	_IOW(TV_MAJOR, 4, /*void*/ 0)
#define IOCTL_TV_GET_CAPS	_IOR(TV_MAJOR, 5, struct tv_caps_t *)


#endif /* TV_H */
